"""This module contains the general information for EquipmentChassisFsmStage ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentChassisFsmStageConsts:
    LAST_UPDATE_TIME_ = ""
    NAME_ASSOCIATE_ACTIVATE_ADAPTOR = "AssociateActivateAdaptor"
    NAME_ASSOCIATE_ACTIVATE_BRD_CTLR = "AssociateActivateBrdCtlr"
    NAME_ASSOCIATE_ACTIVATE_CMC = "AssociateActivateCmc"
    NAME_ASSOCIATE_ACTIVATE_LOCAL_DISK = "AssociateActivateLocalDisk"
    NAME_ASSOCIATE_ACTIVATE_SAS_EXPANDER = "AssociateActivateSasExpander"
    NAME_ASSOCIATE_ACTIVATE_STORAGE_CTLR = "AssociateActivateStorageCtlr"
    NAME_ASSOCIATE_BEGIN = "AssociateBegin"
    NAME_ASSOCIATE_CHASSIS_PEER_ADAPTER_REBOOT = "AssociateChassisPeerAdapterReboot"
    NAME_ASSOCIATE_CONFIG_CHASSIS_ADAPTER_CONNECTIVITY = "AssociateConfigChassisAdapterConnectivity"
    NAME_ASSOCIATE_COPY_REMOTE = "AssociateCopyRemote"
    NAME_ASSOCIATE_DELETE_CURL_DOWNLOADED_IMAGES = "AssociateDeleteCurlDownloadedImages"
    NAME_ASSOCIATE_DELETE_IMAGES_REMOTE = "AssociateDeleteImagesRemote"
    NAME_ASSOCIATE_DISK_ZONING_CONFIG = "AssociateDiskZoningConfig"
    NAME_ASSOCIATE_DOWNLOAD_IMAGES = "AssociateDownloadImages"
    NAME_ASSOCIATE_FAIL = "AssociateFail"
    NAME_ASSOCIATE_POLL_ADAPTOR_ACTIVATION = "AssociatePollAdaptorActivation"
    NAME_ASSOCIATE_POLL_BRD_CTLR_ACTIVATION = "AssociatePollBrdCtlrActivation"
    NAME_ASSOCIATE_POLL_CMC_ACTIVATION = "AssociatePollCmcActivation"
    NAME_ASSOCIATE_POLL_POST_DISK_ZONE_STORAGE_INV_CIMC = "AssociatePollPostDiskZoneStorageInvCIMC"
    NAME_ASSOCIATE_POLL_SAS_EXPANDER_ACTIVATE = "AssociatePollSasExpanderActivate"
    NAME_ASSOCIATE_POLL_SAS_EXPANDER_CONFIG = "AssociatePollSasExpanderConfig"
    NAME_ASSOCIATE_POLL_STORAGE_CTLR_ACTIVATION = "AssociatePollStorageCtlrActivation"
    NAME_ASSOCIATE_POLL_UPDATE_ADAPTOR = "AssociatePollUpdateAdaptor"
    NAME_ASSOCIATE_POLL_UPDATE_CMC = "AssociatePollUpdateCmc"
    NAME_ASSOCIATE_POLL_UPDATE_SAS_EXPANDER = "AssociatePollUpdateSasExpander"
    NAME_ASSOCIATE_POST_DISK_ZONE_STORAGE_INV_CIMC = "AssociatePostDiskZoneStorageInvCIMC"
    NAME_ASSOCIATE_POST_DISK_ZONE_STORAGE_INV_CMC = "AssociatePostDiskZoneStorageInvCMC"
    NAME_ASSOCIATE_POWER_OFF_SERVERS = "AssociatePowerOffServers"
    NAME_ASSOCIATE_POWER_ON_SERVERS = "AssociatePowerOnServers"
    NAME_ASSOCIATE_SAS_EXPANDER_CONFIG = "AssociateSasExpanderConfig"
    NAME_ASSOCIATE_SUCCESS = "AssociateSuccess"
    NAME_ASSOCIATE_UNLOCK_FIRMWARE_IMAGE = "AssociateUnlockFirmwareImage"
    NAME_ASSOCIATE_UPDATE_ADAPTOR = "AssociateUpdateAdaptor"
    NAME_ASSOCIATE_UPDATE_CMC = "AssociateUpdateCmc"
    NAME_ASSOCIATE_UPDATE_SAS_EXPANDER = "AssociateUpdateSasExpander"
    NAME_ASSOCIATE_WAIT_BEFORE_INSTALLATION = "AssociateWaitBeforeInstallation"
    NAME_ASSOCIATE_WAIT_FOR_POWER_OFF = "AssociateWaitForPowerOff"
    NAME_CHASSIS_UPGRADE_ACTIVATE_ADAPTOR = "ChassisUpgradeActivateAdaptor"
    NAME_CHASSIS_UPGRADE_ACTIVATE_BRD_CTLR = "ChassisUpgradeActivateBrdCtlr"
    NAME_CHASSIS_UPGRADE_ACTIVATE_CMC = "ChassisUpgradeActivateCmc"
    NAME_CHASSIS_UPGRADE_ACTIVATE_LOCAL_DISK = "ChassisUpgradeActivateLocalDisk"
    NAME_CHASSIS_UPGRADE_ACTIVATE_SAS_EXPANDER = "ChassisUpgradeActivateSasExpander"
    NAME_CHASSIS_UPGRADE_ACTIVATE_STORAGE_CTLR = "ChassisUpgradeActivateStorageCtlr"
    NAME_CHASSIS_UPGRADE_BEGIN = "ChassisUpgradeBegin"
    NAME_CHASSIS_UPGRADE_FAIL = "ChassisUpgradeFail"
    NAME_CHASSIS_UPGRADE_POLL_ADAPTOR_ACTIVATION = "ChassisUpgradePollAdaptorActivation"
    NAME_CHASSIS_UPGRADE_POLL_BRD_CTLR_ACTIVATION = "ChassisUpgradePollBrdCtlrActivation"
    NAME_CHASSIS_UPGRADE_POLL_CMC_ACTIVATION = "ChassisUpgradePollCmcActivation"
    NAME_CHASSIS_UPGRADE_POLL_LOCAL_DISK_ACTIVATE = "ChassisUpgradePollLocalDiskActivate"
    NAME_CHASSIS_UPGRADE_POLL_SAS_EXPANDER_ACTIVATE = "ChassisUpgradePollSasExpanderActivate"
    NAME_CHASSIS_UPGRADE_POLL_STORAGE_CTLR_ACTIVATION = "ChassisUpgradePollStorageCtlrActivation"
    NAME_CHASSIS_UPGRADE_POLL_UPDATE_STATUS = "ChassisUpgradePollUpdateStatus"
    NAME_CHASSIS_UPGRADE_POWER_OFF_SERVERS = "ChassisUpgradePowerOffServers"
    NAME_CHASSIS_UPGRADE_POWER_ON_SERVERS = "ChassisUpgradePowerOnServers"
    NAME_CHASSIS_UPGRADE_RESET_SAS_EXPANDER = "ChassisUpgradeResetSasExpander"
    NAME_CHASSIS_UPGRADE_SUCCESS = "ChassisUpgradeSuccess"
    NAME_CHASSIS_UPGRADE_UPDATE_REQUEST = "ChassisUpgradeUpdateRequest"
    NAME_CHASSIS_UPGRADE_WAIT_FOR_POWER_OFF = "ChassisUpgradeWaitForPowerOff"
    NAME_DISASSOCIATE_BEGIN = "DisassociateBegin"
    NAME_DISASSOCIATE_COMPLETE = "DisassociateComplete"
    NAME_DISASSOCIATE_FAIL = "DisassociateFail"
    NAME_DISASSOCIATE_SUCCESS = "DisassociateSuccess"
    NAME_DYNAMIC_REALLOCATION_BEGIN = "DynamicReallocationBegin"
    NAME_DYNAMIC_REALLOCATION_CONFIG = "DynamicReallocationConfig"
    NAME_DYNAMIC_REALLOCATION_FAIL = "DynamicReallocationFail"
    NAME_DYNAMIC_REALLOCATION_SUCCESS = "DynamicReallocationSuccess"
    NAME_FAN_POLICY_CONFIG_BEGIN = "FanPolicyConfigBegin"
    NAME_FAN_POLICY_CONFIG_EXECUTE = "FanPolicyConfigExecute"
    NAME_FAN_POLICY_CONFIG_FAIL = "FanPolicyConfigFail"
    NAME_FAN_POLICY_CONFIG_SUCCESS = "FanPolicyConfigSuccess"
    NAME_FW_UPGRADE_BEGIN = "FwUpgradeBegin"
    NAME_FW_UPGRADE_COPY_REMOTE = "FwUpgradeCopyRemote"
    NAME_FW_UPGRADE_DELETE_CURL_DOWNLOADED_IMAGES = "FwUpgradeDeleteCurlDownloadedImages"
    NAME_FW_UPGRADE_DELETE_IMAGES_REMOTE = "FwUpgradeDeleteImagesRemote"
    NAME_FW_UPGRADE_DOWNLOAD_IMAGES = "FwUpgradeDownloadImages"
    NAME_FW_UPGRADE_FAIL = "FwUpgradeFail"
    NAME_FW_UPGRADE_POLL_UPDATE_ADAPTOR = "FwUpgradePollUpdateAdaptor"
    NAME_FW_UPGRADE_POLL_UPDATE_CMC = "FwUpgradePollUpdateCmc"
    NAME_FW_UPGRADE_POLL_UPDATE_SAS_EXPANDER = "FwUpgradePollUpdateSasExpander"
    NAME_FW_UPGRADE_SUCCESS = "FwUpgradeSuccess"
    NAME_FW_UPGRADE_UNLOCK_FIRMWARE_IMAGE = "FwUpgradeUnlockFirmwareImage"
    NAME_FW_UPGRADE_UPDATE_ADAPTOR = "FwUpgradeUpdateAdaptor"
    NAME_FW_UPGRADE_UPDATE_CMC = "FwUpgradeUpdateCmc"
    NAME_FW_UPGRADE_UPDATE_SAS_EXPANDER = "FwUpgradeUpdateSasExpander"
    NAME_FW_UPGRADE_WAIT_BEFORE_INSTALLATION = "FwUpgradeWaitBeforeInstallation"
    NAME_OOB_STORAGE_ADMIN_CFG_BEGIN = "OobStorageAdminCfgBegin"
    NAME_OOB_STORAGE_ADMIN_CFG_FAIL = "OobStorageAdminCfgFail"
    NAME_OOB_STORAGE_ADMIN_CFG_OOB_STORAGE_CONFIG = "OobStorageAdminCfgOobStorageConfig"
    NAME_OOB_STORAGE_ADMIN_CFG_OOB_STORAGE_INVENTORY = "OobStorageAdminCfgOobStorageInventory"
    NAME_OOB_STORAGE_ADMIN_CFG_SUCCESS = "OobStorageAdminCfgSuccess"
    NAME_POWER_CAP_BEGIN = "PowerCapBegin"
    NAME_POWER_CAP_CONFIG = "PowerCapConfig"
    NAME_POWER_CAP_FAIL = "PowerCapFail"
    NAME_POWER_CAP_SUCCESS = "PowerCapSuccess"
    NAME_POWER_CAP_WAIT = "PowerCapWait"
    NAME_POWER_SAVE_POLICY_CONFIG_BEGIN = "PowerSavePolicyConfigBegin"
    NAME_POWER_SAVE_POLICY_CONFIG_EXECUTE = "PowerSavePolicyConfigExecute"
    NAME_POWER_SAVE_POLICY_CONFIG_FAIL = "PowerSavePolicyConfigFail"
    NAME_POWER_SAVE_POLICY_CONFIG_SUCCESS = "PowerSavePolicyConfigSuccess"
    NAME_PSU_POLICY_CONFIG_BEGIN = "PsuPolicyConfigBegin"
    NAME_PSU_POLICY_CONFIG_EXECUTE = "PsuPolicyConfigExecute"
    NAME_PSU_POLICY_CONFIG_FAIL = "PsuPolicyConfigFail"
    NAME_PSU_POLICY_CONFIG_SUCCESS = "PsuPolicyConfigSuccess"
    NAME_REMOVE_CHASSIS_BEGIN = "RemoveChassisBegin"
    NAME_REMOVE_CHASSIS_CLEANUP_VNICS_LOCAL = "RemoveChassisCleanupVnicsLocal"
    NAME_REMOVE_CHASSIS_CLEANUP_VNICS_PEER = "RemoveChassisCleanupVnicsPeer"
    NAME_REMOVE_CHASSIS_DECOMISSION = "RemoveChassisDecomission"
    NAME_REMOVE_CHASSIS_DISABLE_END_POINT = "RemoveChassisDisableEndPoint"
    NAME_REMOVE_CHASSIS_FAIL = "RemoveChassisFail"
    NAME_REMOVE_CHASSIS_SUCCESS = "RemoveChassisSuccess"
    NAME_REMOVE_CHASSIS_UN_IDENTIFY_LOCAL = "RemoveChassisUnIdentifyLocal"
    NAME_REMOVE_CHASSIS_UN_IDENTIFY_PEER = "RemoveChassisUnIdentifyPeer"
    NAME_REMOVE_CHASSIS_WAIT = "RemoveChassisWait"
    NAME_NOP = "nop"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class EquipmentChassisFsmStage(ManagedObject):
    """This is EquipmentChassisFsmStage class."""

    consts = EquipmentChassisFsmStageConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("EquipmentChassisFsmStage", "equipmentChassisFsmStage", "stage-[name]", VersionMeta.Version211a, "OutputOnly", 0xf, [], [""], ['equipmentChassisFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, None, None, None, None, ["AssociateActivateAdaptor", "AssociateActivateBrdCtlr", "AssociateActivateCmc", "AssociateActivateLocalDisk", "AssociateActivateSasExpander", "AssociateActivateStorageCtlr", "AssociateBegin", "AssociateChassisPeerAdapterReboot", "AssociateConfigChassisAdapterConnectivity", "AssociateCopyRemote", "AssociateDeleteCurlDownloadedImages", "AssociateDeleteImagesRemote", "AssociateDiskZoningConfig", "AssociateDownloadImages", "AssociateFail", "AssociatePollAdaptorActivation", "AssociatePollBrdCtlrActivation", "AssociatePollCmcActivation", "AssociatePollPostDiskZoneStorageInvCIMC", "AssociatePollSasExpanderActivate", "AssociatePollSasExpanderConfig", "AssociatePollStorageCtlrActivation", "AssociatePollUpdateAdaptor", "AssociatePollUpdateCmc", "AssociatePollUpdateSasExpander", "AssociatePostDiskZoneStorageInvCIMC", "AssociatePostDiskZoneStorageInvCMC", "AssociatePowerOffServers", "AssociatePowerOnServers", "AssociateSasExpanderConfig", "AssociateSuccess", "AssociateUnlockFirmwareImage", "AssociateUpdateAdaptor", "AssociateUpdateCmc", "AssociateUpdateSasExpander", "AssociateWaitBeforeInstallation", "AssociateWaitForPowerOff", "ChassisUpgradeActivateAdaptor", "ChassisUpgradeActivateBrdCtlr", "ChassisUpgradeActivateCmc", "ChassisUpgradeActivateLocalDisk", "ChassisUpgradeActivateSasExpander", "ChassisUpgradeActivateStorageCtlr", "ChassisUpgradeBegin", "ChassisUpgradeFail", "ChassisUpgradePollAdaptorActivation", "ChassisUpgradePollBrdCtlrActivation", "ChassisUpgradePollCmcActivation", "ChassisUpgradePollLocalDiskActivate", "ChassisUpgradePollSasExpanderActivate", "ChassisUpgradePollStorageCtlrActivation", "ChassisUpgradePollUpdateStatus", "ChassisUpgradePowerOffServers", "ChassisUpgradePowerOnServers", "ChassisUpgradeResetSasExpander", "ChassisUpgradeSuccess", "ChassisUpgradeUpdateRequest", "ChassisUpgradeWaitForPowerOff", "DisassociateBegin", "DisassociateComplete", "DisassociateFail", "DisassociateSuccess", "DynamicReallocationBegin", "DynamicReallocationConfig", "DynamicReallocationFail", "DynamicReallocationSuccess", "FanPolicyConfigBegin", "FanPolicyConfigExecute", "FanPolicyConfigFail", "FanPolicyConfigSuccess", "FwUpgradeBegin", "FwUpgradeCopyRemote", "FwUpgradeDeleteCurlDownloadedImages", "FwUpgradeDeleteImagesRemote", "FwUpgradeDownloadImages", "FwUpgradeFail", "FwUpgradePollUpdateAdaptor", "FwUpgradePollUpdateCmc", "FwUpgradePollUpdateSasExpander", "FwUpgradeSuccess", "FwUpgradeUnlockFirmwareImage", "FwUpgradeUpdateAdaptor", "FwUpgradeUpdateCmc", "FwUpgradeUpdateSasExpander", "FwUpgradeWaitBeforeInstallation", "OobStorageAdminCfgBegin", "OobStorageAdminCfgFail", "OobStorageAdminCfgOobStorageConfig", "OobStorageAdminCfgOobStorageInventory", "OobStorageAdminCfgSuccess", "PowerCapBegin", "PowerCapConfig", "PowerCapFail", "PowerCapSuccess", "PowerCapWait", "PowerSavePolicyConfigBegin", "PowerSavePolicyConfigExecute", "PowerSavePolicyConfigFail", "PowerSavePolicyConfigSuccess", "PsuPolicyConfigBegin", "PsuPolicyConfigExecute", "PsuPolicyConfigFail", "PsuPolicyConfigSuccess", "RemoveChassisBegin", "RemoveChassisCleanupVnicsLocal", "RemoveChassisCleanupVnicsPeer", "RemoveChassisDecomission", "RemoveChassisDisableEndPoint", "RemoveChassisFail", "RemoveChassisSuccess", "RemoveChassisUnIdentifyLocal", "RemoveChassisUnIdentifyPeer", "RemoveChassisWait", "nop"], []),
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.sacl = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "EquipmentChassisFsmStage", parent_mo_or_dn, **kwargs)



"""This module contains the general information for SysdebugMEpLog ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SysdebugMEpLogConsts:
    ADMIN_STATE_BACKUP = "backup"
    ADMIN_STATE_CLEAR = "clear"
    ADMIN_STATE_POLICY = "policy"
    CAPACITY_AVAILABLE = "available"
    CAPACITY_FULL = "full"
    CAPACITY_LOW = "low"
    CAPACITY_UNKNOWN = "unknown"
    CAPACITY_VERY_LOW = "very-low"
    LAST_UPDATE_NEVER = "never"
    OPER_STATE_BMC_COMMUNICATION_ERROR = "bmc-communication-error"
    OPER_STATE_INTERNAL_UCSM_ERROR = "internal-ucsm-error"
    OPER_STATE_OK = "ok"
    OPER_STATE_PERMISSION_DENIED_ERROR = "permission-denied-error"
    OPER_STATE_REMOTE_COMMUNICATION_ERROR = "remote-communication-error"
    TYPE_OBFL = "OBFL"
    TYPE_SEL = "SEL"
    TYPE_SYSLOG = "Syslog"


class SysdebugMEpLog(ManagedObject):
    """This is SysdebugMEpLog class."""

    consts = SysdebugMEpLogConsts()
    naming_props = set(['type', 'id'])

    mo_meta = MoMeta("SysdebugMEpLog", "sysdebugMEpLog", "log-[type]-[id]", VersionMeta.Version101e, "InputOutput", 0xff, [], ["admin", "operations"], ['mgmtController'], ['faultInst'], ["Get", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["backup", "clear", "policy"], []),
        "capacity": MoPropertyMeta("capacity", "capacity", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["available", "full", "low", "unknown", "very-low"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "byte", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x10, None, None, None, [], ["0-8"]),
        "last_update": MoPropertyMeta("last_update", "lastUpdate", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["bmc-communication-error", "internal-ucsm-error", "ok", "permission-denied-error", "remote-communication-error"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x80, None, None, None, ["OBFL", "SEL", "Syslog"], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "capacity": "capacity", 
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "lastUpdate": "last_update", 
        "operState": "oper_state", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, type, id, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.id = id
        self.admin_state = None
        self.capacity = None
        self.child_action = None
        self.last_update = None
        self.oper_state = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "SysdebugMEpLog", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ApeMenloVnic ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ApeMenloVnicConsts:
    STATE_CREATE_PEND = "CreatePend"
    STATE_CREATING = "Creating"
    STATE_DESTROY_PEND = "DestroyPend"
    STATE_DESTROYING = "Destroying"
    STATE_MODIFY_PEND = "ModifyPend"
    STATE_MODIFYING = "Modifying"
    STATE_PRESENT = "Present"
    STATE_UNKNOWN = "Unknown"
    TYPE_ETH = "Eth"
    TYPE_FC = "Fc"
    TYPE_SCSI = "Scsi"
    TYPE_UNKNOWN = "Unknown"


class ApeMenloVnic(ManagedObject):
    """This is ApeMenloVnic class."""

    consts = ApeMenloVnicConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("ApeMenloVnic", "apeMenloVnic", "AdapterVnic-[name]", VersionMeta.Version101e, "InputOutput", 0x3ffff, [], ["read-only"], ['apeMenlo', 'apePalo'], ['apeMenloVnicStats', 'apePaloVnicStats'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "cookie": MoPropertyMeta("cookie", "cookie", "ulong", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, [], []),
        "cos": MoPropertyMeta("cos", "cos", "byte", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "mac": MoPropertyMeta("mac", "mac", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "nic_dn": MoPropertyMeta("nic_dn", "nicDn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "pif_id": MoPropertyMeta("pif_id", "pifId", "byte", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "state": MoPropertyMeta("state", "state", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["CreatePend", "Creating", "DestroyPend", "Destroying", "ModifyPend", "Modifying", "Present", "Unknown"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["Eth", "Fc", "Scsi", "Unknown"], []),
        "uplink_port_id": MoPropertyMeta("uplink_port_id", "uplinkPortId", "byte", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, [], []),
        "vif_id": MoPropertyMeta("vif_id", "vifId", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x1000, None, None, None, [], []),
        "vif_type": MoPropertyMeta("vif_type", "vifType", "byte", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x2000, None, None, None, [], []),
        "vlan_id": MoPropertyMeta("vlan_id", "vlanId", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4000, None, None, None, [], []),
        "vntag": MoPropertyMeta("vntag", "vntag", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8000, None, None, None, [], []),
        "wwnn": MoPropertyMeta("wwnn", "wwnn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10000, 0, 256, r"""(([A-Fa-f0-9][A-Fa-f0-9]:){7}[A-Fa-f0-9][A-Fa-f0-9])|0""", [], []),
        "wwpn": MoPropertyMeta("wwpn", "wwpn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20000, 0, 256, r"""(([A-Fa-f0-9][A-Fa-f0-9]:){7}[A-Fa-f0-9][A-Fa-f0-9])|0""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "cookie": "cookie", 
        "cos": "cos", 
        "dn": "dn", 
        "mac": "mac", 
        "name": "name", 
        "nicDn": "nic_dn", 
        "pifId": "pif_id", 
        "rn": "rn", 
        "sacl": "sacl", 
        "state": "state", 
        "status": "status", 
        "type": "type", 
        "uplinkPortId": "uplink_port_id", 
        "vifId": "vif_id", 
        "vifType": "vif_type", 
        "vlanId": "vlan_id", 
        "vntag": "vntag", 
        "wwnn": "wwnn", 
        "wwpn": "wwpn", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.cookie = None
        self.cos = None
        self.mac = None
        self.nic_dn = None
        self.pif_id = None
        self.sacl = None
        self.state = None
        self.status = None
        self.type = None
        self.uplink_port_id = None
        self.vif_id = None
        self.vif_type = None
        self.vlan_id = None
        self.vntag = None
        self.wwnn = None
        self.wwpn = None

        ManagedObject.__init__(self, "ApeMenloVnic", parent_mo_or_dn, **kwargs)



"""This module contains the general information for StorageNvmeSwitch ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class StorageNvmeSwitchConsts:
    DISASTER_RECOVERY_COMPLETED = "completed"
    DISASTER_RECOVERY_FAILED = "failed"
    DISASTER_RECOVERY_IN_PROGRESS = "in-progress"
    DISASTER_RECOVERY_NOT_PERFORMED = "not-performed"
    DISASTER_RECOVERY_READY = "ready"
    DISASTER_RECOVERY_TRIGGERED = "triggered"
    DISASTER_RECOVERY_UNKNOWN = "unknown"
    LINK_STATUS_DEGRADED = "degraded"
    LINK_STATUS_DELETED = "deleted"
    LINK_STATUS_FAILED = "failed"
    LINK_STATUS_FLASH_FAILED = "flash-failed"
    LINK_STATUS_MODERATE_FAULT = "moderate-fault"
    LINK_STATUS_OPTIMAL = "optimal"
    LINK_STATUS_SEVERE_FAULT = "severe-fault"
    LINK_STATUS_UNKNOWN = "unknown"
    LINK_STATUS_UNRESPONSIVE = "unresponsive"
    M_STATUS_DEGRADED = "degraded"
    M_STATUS_DELETED = "deleted"
    M_STATUS_FAILED = "failed"
    M_STATUS_FLASH_FAILED = "flash-failed"
    M_STATUS_MODERATE_FAULT = "moderate-fault"
    M_STATUS_OPTIMAL = "optimal"
    M_STATUS_SEVERE_FAULT = "severe-fault"
    M_STATUS_UNKNOWN = "unknown"
    M_STATUS_UNRESPONSIVE = "unresponsive"
    OPER_STATE_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPER_STATE_AUTO_UPGRADE = "auto-upgrade"
    OPER_STATE_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPER_STATE_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPER_STATE_CHASSIS_INTRUSION = "chassis-intrusion"
    OPER_STATE_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPER_STATE_CONFIG = "config"
    OPER_STATE_DECOMISSIONING = "decomissioning"
    OPER_STATE_DEGRADED = "degraded"
    OPER_STATE_DISABLED = "disabled"
    OPER_STATE_DISCOVERY = "discovery"
    OPER_STATE_DISCOVERY_FAILED = "discovery-failed"
    OPER_STATE_EQUIPMENT_PROBLEM = "equipment-problem"
    OPER_STATE_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPER_STATE_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPER_STATE_IDENTIFY = "identify"
    OPER_STATE_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPER_STATE_INOPERABLE = "inoperable"
    OPER_STATE_LINK_ACTIVATE_BLOCKED = "link-activate-blocked"
    OPER_STATE_MALFORMED_FRU = "malformed-fru"
    OPER_STATE_NON_OPTIMAL = "non-optimal"
    OPER_STATE_NON_OPTIMAL_SEVERE = "non-optimal-severe"
    OPER_STATE_NOT_SUPPORTED = "not-supported"
    OPER_STATE_OPERABLE = "operable"
    OPER_STATE_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPER_STATE_PERFORMANCE_PROBLEM = "performance-problem"
    OPER_STATE_POST_FAILURE = "post-failure"
    OPER_STATE_POWER_PROBLEM = "power-problem"
    OPER_STATE_POWERED_OFF = "powered-off"
    OPER_STATE_REMOVED = "removed"
    OPER_STATE_THERMAL_PROBLEM = "thermal-problem"
    OPER_STATE_UNKNOWN = "unknown"
    OPER_STATE_UNSUPPORTED_CONFIG = "unsupported-config"
    OPER_STATE_UPGRADE_PROBLEM = "upgrade-problem"
    OPER_STATE_VOLTAGE_PROBLEM = "voltage-problem"
    OPERABILITY_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPERABILITY_AUTO_UPGRADE = "auto-upgrade"
    OPERABILITY_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPERABILITY_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPERABILITY_CHASSIS_INTRUSION = "chassis-intrusion"
    OPERABILITY_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPERABILITY_CONFIG = "config"
    OPERABILITY_DECOMISSIONING = "decomissioning"
    OPERABILITY_DEGRADED = "degraded"
    OPERABILITY_DISABLED = "disabled"
    OPERABILITY_DISCOVERY = "discovery"
    OPERABILITY_DISCOVERY_FAILED = "discovery-failed"
    OPERABILITY_EQUIPMENT_PROBLEM = "equipment-problem"
    OPERABILITY_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPERABILITY_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPERABILITY_IDENTIFY = "identify"
    OPERABILITY_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPERABILITY_INOPERABLE = "inoperable"
    OPERABILITY_LINK_ACTIVATE_BLOCKED = "link-activate-blocked"
    OPERABILITY_MALFORMED_FRU = "malformed-fru"
    OPERABILITY_NON_OPTIMAL = "non-optimal"
    OPERABILITY_NON_OPTIMAL_SEVERE = "non-optimal-severe"
    OPERABILITY_NOT_SUPPORTED = "not-supported"
    OPERABILITY_OPERABLE = "operable"
    OPERABILITY_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPERABILITY_PERFORMANCE_PROBLEM = "performance-problem"
    OPERABILITY_POST_FAILURE = "post-failure"
    OPERABILITY_POWER_PROBLEM = "power-problem"
    OPERABILITY_POWERED_OFF = "powered-off"
    OPERABILITY_REMOVED = "removed"
    OPERABILITY_THERMAL_PROBLEM = "thermal-problem"
    OPERABILITY_UNKNOWN = "unknown"
    OPERABILITY_UNSUPPORTED_CONFIG = "unsupported-config"
    OPERABILITY_UPGRADE_PROBLEM = "upgrade-problem"
    OPERABILITY_VOLTAGE_PROBLEM = "voltage-problem"
    PERF_LOWER_CRITICAL = "lower-critical"
    PERF_LOWER_NON_CRITICAL = "lower-non-critical"
    PERF_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    PERF_NOT_SUPPORTED = "not-supported"
    PERF_OK = "ok"
    PERF_UNKNOWN = "unknown"
    PERF_UPPER_CRITICAL = "upper-critical"
    PERF_UPPER_NON_CRITICAL = "upper-non-critical"
    PERF_UPPER_NON_RECOVERABLE = "upper-non-recoverable"
    POWER_DEGRADED = "degraded"
    POWER_ERROR = "error"
    POWER_FAILED = "failed"
    POWER_NOT_SUPPORTED = "not-supported"
    POWER_OFF = "off"
    POWER_OFFDUTY = "offduty"
    POWER_OFFLINE = "offline"
    POWER_OK = "ok"
    POWER_ON = "on"
    POWER_ONLINE = "online"
    POWER_POWER_SAVE = "power-save"
    POWER_TEST = "test"
    POWER_UNKNOWN = "unknown"
    PRESENCE_EMPTY = "empty"
    PRESENCE_EQUIPPED = "equipped"
    PRESENCE_EQUIPPED_DEPRECATED = "equipped-deprecated"
    PRESENCE_EQUIPPED_DISC_ERROR = "equipped-disc-error"
    PRESENCE_EQUIPPED_DISC_IN_PROGRESS = "equipped-disc-in-progress"
    PRESENCE_EQUIPPED_DISC_NOT_STARTED = "equipped-disc-not-started"
    PRESENCE_EQUIPPED_DISC_UNKNOWN = "equipped-disc-unknown"
    PRESENCE_EQUIPPED_IDENTITY_UNESTABLISHABLE = "equipped-identity-unestablishable"
    PRESENCE_EQUIPPED_NOT_PRIMARY = "equipped-not-primary"
    PRESENCE_EQUIPPED_SLAVE = "equipped-slave"
    PRESENCE_EQUIPPED_UNSUPPORTED = "equipped-unsupported"
    PRESENCE_EQUIPPED_WITH_MALFORMED_FRU = "equipped-with-malformed-fru"
    PRESENCE_INACCESSIBLE = "inaccessible"
    PRESENCE_MISMATCH = "mismatch"
    PRESENCE_MISMATCH_IDENTITY_UNESTABLISHABLE = "mismatch-identity-unestablishable"
    PRESENCE_MISMATCH_SLAVE = "mismatch-slave"
    PRESENCE_MISSING = "missing"
    PRESENCE_MISSING_SLAVE = "missing-slave"
    PRESENCE_NOT_SUPPORTED = "not-supported"
    PRESENCE_UNAUTHORIZED = "unauthorized"
    PRESENCE_UNKNOWN = "unknown"
    SWITCH_STATUS_DEGRADED = "degraded"
    SWITCH_STATUS_DELETED = "deleted"
    SWITCH_STATUS_FAILED = "failed"
    SWITCH_STATUS_FLASH_FAILED = "flash-failed"
    SWITCH_STATUS_MODERATE_FAULT = "moderate-fault"
    SWITCH_STATUS_OPTIMAL = "optimal"
    SWITCH_STATUS_SEVERE_FAULT = "severe-fault"
    SWITCH_STATUS_UNKNOWN = "unknown"
    SWITCH_STATUS_UNRESPONSIVE = "unresponsive"
    TEMPERATURE_NOT_APPLICABLE = "not-applicable"
    THERMAL_LOWER_CRITICAL = "lower-critical"
    THERMAL_LOWER_NON_CRITICAL = "lower-non-critical"
    THERMAL_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    THERMAL_NOT_SUPPORTED = "not-supported"
    THERMAL_OK = "ok"
    THERMAL_UNKNOWN = "unknown"
    THERMAL_UPPER_CRITICAL = "upper-critical"
    THERMAL_UPPER_NON_CRITICAL = "upper-non-critical"
    THERMAL_UPPER_NON_RECOVERABLE = "upper-non-recoverable"
    TYPE_DIRECT_ATTACHED = "DIRECT-ATTACHED"
    TYPE_HHHL = "HHHL"
    TYPE_MSWITCH = "MSWITCH"
    TYPE_UNKNOWN = "UNKNOWN"
    VOLTAGE_LOWER_CRITICAL = "lower-critical"
    VOLTAGE_LOWER_NON_CRITICAL = "lower-non-critical"
    VOLTAGE_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    VOLTAGE_NOT_SUPPORTED = "not-supported"
    VOLTAGE_OK = "ok"
    VOLTAGE_UNKNOWN = "unknown"
    VOLTAGE_UPPER_CRITICAL = "upper-critical"
    VOLTAGE_UPPER_NON_CRITICAL = "upper-non-critical"
    VOLTAGE_UPPER_NON_RECOVERABLE = "upper-non-recoverable"


class StorageNvmeSwitch(ManagedObject):
    """This is StorageNvmeSwitch class."""

    consts = StorageNvmeSwitchConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("StorageNvmeSwitch", "storageNvmeSwitch", "nvme-switch-[id]", VersionMeta.Version323a, "InputOutput", 0x7f, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-storage"], ['computeBoard'], ['faultInst', 'firmwareBootDefinition', 'firmwareRunning'], [None])

    prop_meta = {
        "bus_address": MoPropertyMeta("bus_address", "busAddress", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version323a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "component_id": MoPropertyMeta("component_id", "componentId", "uint", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "disaster_recovery": MoPropertyMeta("disaster_recovery", "disasterRecovery", "string", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["completed", "failed", "in-progress", "not-performed", "ready", "triggered", "unknown"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "drive_count": MoPropertyMeta("drive_count", "driveCount", "uint", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version323a, MoPropertyMeta.NAMING, 0x10, None, None, None, [], ["0-4294967295"]),
        "link_status": MoPropertyMeta("link_status", "linkStatus", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["degraded", "deleted", "failed", "flash-failed", "moderate-fault", "optimal", "severe-fault", "unknown", "unresponsive"], []),
        "location_dn": MoPropertyMeta("location_dn", "locationDn", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "m_status": MoPropertyMeta("m_status", "mStatus", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["degraded", "deleted", "failed", "flash-failed", "moderate-fault", "optimal", "severe-fault", "unknown", "unresponsive"], []),
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "oper_qualifier_reason": MoPropertyMeta("oper_qualifier_reason", "operQualifierReason", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-intrusion", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "link-activate-blocked", "malformed-fru", "non-optimal", "non-optimal-severe", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "unsupported-config", "upgrade-problem", "voltage-problem"], []),
        "operability": MoPropertyMeta("operability", "operability", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-intrusion", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "link-activate-blocked", "malformed-fru", "non-optimal", "non-optimal-severe", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "unsupported-config", "upgrade-problem", "voltage-problem"], []),
        "perf": MoPropertyMeta("perf", "perf", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []),
        "power": MoPropertyMeta("power", "power", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["degraded", "error", "failed", "not-supported", "off", "offduty", "offline", "ok", "on", "online", "power-save", "test", "unknown"], []),
        "presence": MoPropertyMeta("presence", "presence", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "equipped", "equipped-deprecated", "equipped-disc-error", "equipped-disc-in-progress", "equipped-disc-not-started", "equipped-disc-unknown", "equipped-identity-unestablishable", "equipped-not-primary", "equipped-slave", "equipped-unsupported", "equipped-with-malformed-fru", "inaccessible", "mismatch", "mismatch-identity-unestablishable", "mismatch-slave", "missing", "missing-slave", "not-supported", "unauthorized", "unknown"], []),
        "product_id": MoPropertyMeta("product_id", "productId", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "product_revision": MoPropertyMeta("product_revision", "productRevision", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "revision": MoPropertyMeta("revision", "revision", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "serial": MoPropertyMeta("serial", "serial", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version323a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_name": MoPropertyMeta("switch_name", "switchName", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "switch_status": MoPropertyMeta("switch_status", "switchStatus", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["degraded", "deleted", "failed", "flash-failed", "moderate-fault", "optimal", "severe-fault", "unknown", "unresponsive"], []),
        "temperature": MoPropertyMeta("temperature", "temperature", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "thermal": MoPropertyMeta("thermal", "thermal", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["DIRECT-ATTACHED", "HHHL", "MSWITCH", "UNKNOWN"], []),
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "voltage": MoPropertyMeta("voltage", "voltage", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []),
    }

    prop_map = {
        "busAddress": "bus_address", 
        "childAction": "child_action", 
        "componentId": "component_id", 
        "disasterRecovery": "disaster_recovery", 
        "dn": "dn", 
        "driveCount": "drive_count", 
        "id": "id", 
        "linkStatus": "link_status", 
        "locationDn": "location_dn", 
        "mStatus": "m_status", 
        "model": "model", 
        "operQualifierReason": "oper_qualifier_reason", 
        "operState": "oper_state", 
        "operability": "operability", 
        "perf": "perf", 
        "power": "power", 
        "presence": "presence", 
        "productId": "product_id", 
        "productRevision": "product_revision", 
        "revision": "revision", 
        "rn": "rn", 
        "sacl": "sacl", 
        "serial": "serial", 
        "status": "status", 
        "switchName": "switch_name", 
        "switchStatus": "switch_status", 
        "temperature": "temperature", 
        "thermal": "thermal", 
        "type": "type", 
        "vendor": "vendor", 
        "voltage": "voltage", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.bus_address = None
        self.child_action = None
        self.component_id = None
        self.disaster_recovery = None
        self.drive_count = None
        self.link_status = None
        self.location_dn = None
        self.m_status = None
        self.model = None
        self.oper_qualifier_reason = None
        self.oper_state = None
        self.operability = None
        self.perf = None
        self.power = None
        self.presence = None
        self.product_id = None
        self.product_revision = None
        self.revision = None
        self.sacl = None
        self.serial = None
        self.status = None
        self.switch_name = None
        self.switch_status = None
        self.temperature = None
        self.thermal = None
        self.type = None
        self.vendor = None
        self.voltage = None

        ManagedObject.__init__(self, "StorageNvmeSwitch", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ApeHostAgent ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ApeHostAgentConsts:
    CHASSIS_ID_N_A = "N/A"
    STATE_HALTING_HOSTOS = "HALTING_HOSTOS"
    STATE_HALTING_PNUOS = "HALTING_PNUOS"
    STATE_HOSTOS = "HOSTOS"
    STATE_PNUOS = "PNUOS"
    STATE_STARTING_HOSTOS = "STARTING_HOSTOS"
    STATE_STARTING_PNUOS = "STARTING_PNUOS"
    STATE_UNKNOWN = "UNKNOWN"


class ApeHostAgent(ManagedObject):
    """This is ApeHostAgent class."""

    consts = ApeHostAgentConsts()
    naming_props = set(['chassisId', 'slotId'])

    mo_meta = MoMeta("ApeHostAgent", "apeHostAgent", "hostagent-[chassis_id]-[slot_id]", VersionMeta.Version101e, "InputOutput", 0xff, [], ["admin"], ['apeManager'], [], [None])

    prop_meta = {
        "chassis_id": MoPropertyMeta("chassis_id", "chassisId", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x2, None, None, None, ["N/A"], ["0-255"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "server_id": MoPropertyMeta("server_id", "serverId", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], []),
        "slot_id": MoPropertyMeta("slot_id", "slotId", "uint", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x40, None, None, None, [], []),
        "state": MoPropertyMeta("state", "state", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["HALTING_HOSTOS", "HALTING_PNUOS", "HOSTOS", "PNUOS", "STARTING_HOSTOS", "STARTING_PNUOS", "UNKNOWN"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "chassisId": "chassis_id", 
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "sacl": "sacl", 
        "serverId": "server_id", 
        "slotId": "slot_id", 
        "state": "state", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, chassis_id, slot_id, **kwargs):
        self._dirty_mask = 0
        self.chassis_id = chassis_id
        self.slot_id = slot_id
        self.child_action = None
        self.sacl = None
        self.server_id = None
        self.state = None
        self.status = None

        ManagedObject.__init__(self, "ApeHostAgent", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of AaaGetAuthTokenClient ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("AaaGetAuthTokenClient", "aaaGetAuthTokenClient", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_cookie": MethodPropertyMeta("InCookie", "inCookie", "Xs:string", "Version142b", "Input", False),
    "out_tokens": MethodPropertyMeta("OutTokens", "outTokens", "Xs:string", "Version142b", "Output", False),
    "out_user": MethodPropertyMeta("OutUser", "outUser", "Xs:string", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inCookie": "in_cookie",
    "outTokens": "out_tokens",
    "outUser": "out_user",
}



"""This module contains the general information for StorageLocalDiskPartition ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class StorageLocalDiskPartitionConsts:
    BOOTABLE_FALSE = "false"
    BOOTABLE_TRUE = "true"
    BOOTABLE_UNKNOWN = "unknown"
    PARTITION_END_UNKNOWN = "unknown"
    PARTITION_START_UNKNOWN = "unknown"
    SIZE_UNKNOWN = "unknown"
    TYPE_EMPTY = "empty"
    TYPE_EXTENDED = "extended"
    TYPE_LINUX = "linux"
    TYPE_LINUX_LVM = "linux-lvm"
    TYPE_LINUX_SWAP = "linux-swap"


class StorageLocalDiskPartition(ManagedObject):
    """This is StorageLocalDiskPartition class."""

    consts = StorageLocalDiskPartitionConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("StorageLocalDiskPartition", "storageLocalDiskPartition", "partition-[id]", VersionMeta.Version101e, "InputOutput", 0x3ff, [], ["read-only"], ['storageLocalDisk', 'storageLocalDiskConfigDef', 'storageLocalDiskConfigPolicy'], [], ["Get"])

    prop_meta = {
        "bootable": MoPropertyMeta("bootable", "bootable", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "true", "unknown"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version251a, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "partition_end": MoPropertyMeta("partition_end", "partitionEnd", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unknown"], ["0-18446744073709551615"]),
        "partition_start": MoPropertyMeta("partition_start", "partitionStart", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unknown"], ["0-18446744073709551615"]),
        "raw_type_desc": MoPropertyMeta("raw_type_desc", "rawTypeDesc", "string", VersionMeta.Version251a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "size": MoPropertyMeta("size", "size", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["unknown"], ["0-18446744073709551615"]),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["empty", "extended", "linux", "linux-lvm", "linux-swap"], ["0-255"]),
    }

    prop_map = {
        "bootable": "bootable", 
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "name": "name", 
        "partitionEnd": "partition_end", 
        "partitionStart": "partition_start", 
        "rawTypeDesc": "raw_type_desc", 
        "rn": "rn", 
        "sacl": "sacl", 
        "size": "size", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.bootable = None
        self.child_action = None
        self.name = None
        self.partition_end = None
        self.partition_start = None
        self.raw_type_desc = None
        self.sacl = None
        self.size = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "StorageLocalDiskPartition", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ApeControllerEeprom ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ApeControllerEepromConsts:
    SIDE_LEFT = "Left"
    SIDE_RIGHT = "Right"
    SIDE_UNKNOWN = "Unknown"


class ApeControllerEeprom(ManagedObject):
    """This is ApeControllerEeprom class."""

    consts = ApeControllerEepromConsts()
    naming_props = set(['side'])

    mo_meta = MoMeta("ApeControllerEeprom", "apeControllerEeprom", "Eeprom-[side]", VersionMeta.Version101e, "InputOutput", 0x1ff, [], ["read-only"], ['apeControllerChassis'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "database_version": MoPropertyMeta("database_version", "databaseVersion", "ulong", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "heartbeat_request": MoPropertyMeta("heartbeat_request", "heartbeatRequest", "ulong", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], []),
        "heartbeat_response": MoPropertyMeta("heartbeat_response", "heartbeatResponse", "ulong", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "side": MoPropertyMeta("side", "side", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x80, None, None, None, ["Left", "Right", "Unknown"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "databaseVersion": "database_version", 
        "dn": "dn", 
        "heartbeatRequest": "heartbeat_request", 
        "heartbeatResponse": "heartbeat_response", 
        "rn": "rn", 
        "sacl": "sacl", 
        "side": "side", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, side, **kwargs):
        self._dirty_mask = 0
        self.side = side
        self.child_action = None
        self.database_version = None
        self.heartbeat_request = None
        self.heartbeat_response = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "ApeControllerEeprom", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FabricNetflowMonExporter ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FabricNetflowMonExporterConsts:
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    PROTOCOL_NETFLOW = "netflow"
    TRANSPORT_PROTOCOL_SCTP = "sctp"
    TRANSPORT_PROTOCOL_UDP = "udp"
    VERSION_IPFIX = "ipfix"
    VERSION_V9 = "v9"


class FabricNetflowMonExporter(ManagedObject):
    """This is FabricNetflowMonExporter class."""

    consts = FabricNetflowMonExporterConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FabricNetflowMonExporter", "fabricNetflowMonExporter", "lanFlowMonExporter-eth-netflow-[name]", VersionMeta.Version221b, "InputOutput", 0x3fff, [], ["admin", "ext-lan-config", "ext-lan-policy"], ['fabricEthLanFlowMonitoring'], ['faultInst'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version221b, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "dscp": MoPropertyMeta("dscp", "dscp", "ushort", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], ["0-63"]),
        "export_internal": MoPropertyMeta("export_internal", "exportInternal", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "exporter_stats_timeout": MoPropertyMeta("exporter_stats_timeout", "exporterStatsTimeout", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], ["60-86400"]),
        "flow_exp_profile": MoPropertyMeta("flow_exp_profile", "flowExpProfile", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "flow_mon_collector": MoPropertyMeta("flow_mon_collector", "flowMonCollector", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version221b, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "interface_table_timeout": MoPropertyMeta("interface_table_timeout", "interfaceTableTimeout", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, [], ["60-86400"]),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version221b, MoPropertyMeta.NAMING, 0x200, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "oper_flow_exp_profile": MoPropertyMeta("oper_flow_exp_profile", "operFlowExpProfile", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["local", "pending-policy", "policy"], []),
        "protocol": MoPropertyMeta("protocol", "protocol", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["netflow"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x800, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "template_data_timeout": MoPropertyMeta("template_data_timeout", "templateDataTimeout", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x2000, None, None, None, [], ["60-86400"]),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "transport_protocol": MoPropertyMeta("transport_protocol", "transportProtocol", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["sctp", "udp"], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
        "version": MoPropertyMeta("version", "version", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ipfix", "v9"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "dscp": "dscp", 
        "exportInternal": "export_internal", 
        "exporterStatsTimeout": "exporter_stats_timeout", 
        "flowExpProfile": "flow_exp_profile", 
        "flowMonCollector": "flow_mon_collector", 
        "intId": "int_id", 
        "interfaceTableTimeout": "interface_table_timeout", 
        "name": "name", 
        "operFlowExpProfile": "oper_flow_exp_profile", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "protocol": "protocol", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "templateDataTimeout": "template_data_timeout", 
        "transport": "transport", 
        "transportProtocol": "transport_protocol", 
        "type": "type", 
        "version": "version", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.dscp = None
        self.export_internal = None
        self.exporter_stats_timeout = None
        self.flow_exp_profile = None
        self.flow_mon_collector = None
        self.int_id = None
        self.interface_table_timeout = None
        self.oper_flow_exp_profile = None
        self.policy_level = None
        self.policy_owner = None
        self.protocol = None
        self.sacl = None
        self.status = None
        self.template_data_timeout = None
        self.transport = None
        self.transport_protocol = None
        self.type = None
        self.version = None

        ManagedObject.__init__(self, "FabricNetflowMonExporter", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FabricEthMon ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FabricEthMonConsts:
    ADMIN_STATE_DISABLED = "disabled"
    ADMIN_STATE_ENABLED = "enabled"
    ID_A = "A"
    ID_B = "B"
    ID_NONE = "NONE"
    IS_CONFIG_SUCCESS_FALSE = "false"
    IS_CONFIG_SUCCESS_NO = "no"
    IS_CONFIG_SUCCESS_TRUE = "true"
    IS_CONFIG_SUCCESS_YES = "yes"
    OPER_STATE_DOWN = "down"
    OPER_STATE_ERROR = "error"
    OPER_STATE_UNKNOWN = "unknown"
    OPER_STATE_UP = "up"
    OPER_STATE_REASON_ACTIVE = "Active"
    OPER_STATE_REASON_GENERIC_ERROR = "Generic_Error"
    OPER_STATE_REASON_NO_DESTINATION_CONFIGURED = "No_Destination_Configured"
    OPER_STATE_REASON_NO_FLOW_ID_SPECIFIED = "No_Flow-id_Specified"
    OPER_STATE_REASON_NO_HARDWARE_RESOURCE = "No_Hardware_Resource"
    OPER_STATE_REASON_NO_OPERATIONAL_SRC_DST = "No_Operational_Src_Dst"
    OPER_STATE_REASON_NO_SOURCE_DESTINATION_CONFIGURED = "No_Source_Destination_Configured"
    OPER_STATE_REASON_NO_SOURCES_CONFIGURED = "No_Sources_Configured"
    OPER_STATE_REASON_SESSION_ADMIN_SHUT = "Session_Admin_Shut"
    OPER_STATE_REASON_TUNNEL_MISCONF_DOWN = "Tunnel_Misconf_Down"
    OPER_STATE_REASON_UNKNOWN = "Unknown"
    OPER_STATE_REASON_WRONG_DESTINATION_MODE = "Wrong_Destination_Mode"
    OPER_STATE_REASON_WRONG_SOURCE_MODE = "Wrong_Source_Mode"
    SPAN_CTRL_PKTS_DISABLED = "disabled"
    SPAN_CTRL_PKTS_ENABLED = "enabled"


class FabricEthMon(ManagedObject):
    """This is FabricEthMon class."""

    consts = FabricEthMonConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FabricEthMon", "fabricEthMon", "eth-mon-[name]", VersionMeta.Version141i, "InputOutput", 0x1ff, [], ["admin", "ext-lan-config", "ext-lan-policy"], ['fabricEthMonLan'], ['fabricEthMonDestEp', 'fabricEthMonFiltRef', 'fabricEthMonSrcRef', 'fabricSubGroup', 'faultInst'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["disabled", "enabled"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "config_fail_reason": MoPropertyMeta("config_fail_reason", "configFailReason", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version141i, MoPropertyMeta.CREATE_ONLY, 0x10, None, None, None, ["A", "B", "NONE"], []),
        "is_config_success": MoPropertyMeta("is_config_success", "isConfigSuccess", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x20, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, ["down", "error", "unknown", "up"], []),
        "oper_state_reason": MoPropertyMeta("oper_state_reason", "operStateReason", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, ["Active", "Generic_Error", "No_Destination_Configured", "No_Flow-id_Specified", "No_Hardware_Resource", "No_Operational_Src_Dst", "No_Source_Destination_Configured", "No_Sources_Configured", "Session_Admin_Shut", "Tunnel_Misconf_Down", "Unknown", "Wrong_Destination_Mode", "Wrong_Source_Mode"], []),
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "session": MoPropertyMeta("session", "session", "uint", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["1-255"]),
        "span_ctrl_pkts": MoPropertyMeta("span_ctrl_pkts", "spanCtrlPkts", "string", VersionMeta.Version401a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["disabled", "enabled"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "configFailReason": "config_fail_reason", 
        "dn": "dn", 
        "id": "id", 
        "isConfigSuccess": "is_config_success", 
        "locale": "locale", 
        "name": "name", 
        "operState": "oper_state", 
        "operStateReason": "oper_state_reason", 
        "peerDn": "peer_dn", 
        "rn": "rn", 
        "sacl": "sacl", 
        "session": "session", 
        "spanCtrlPkts": "span_ctrl_pkts", 
        "status": "status", 
        "transport": "transport", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.admin_state = None
        self.child_action = None
        self.config_fail_reason = None
        self.id = None
        self.is_config_success = None
        self.locale = None
        self.oper_state = None
        self.oper_state_reason = None
        self.peer_dn = None
        self.sacl = None
        self.session = None
        self.span_ctrl_pkts = None
        self.status = None
        self.transport = None
        self.type = None

        ManagedObject.__init__(self, "FabricEthMon", parent_mo_or_dn, **kwargs)



"""This module contains the general information for MemoryPersistentMemoryConfiguration ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class MemoryPersistentMemoryConfigurationConsts:
    ADMIN_ACTION_CANCEL_ALL = "cancel-all"
    ADMIN_ACTION_DISABLE_SECURITY = "disable-security"
    ADMIN_ACTION_ENABLE_SECURITY = "enable-security"
    ADMIN_ACTION_MODIFY_PASSPHRASE = "modify-passphrase"
    ADMIN_ACTION_NO_OP = "no-op"
    ADMIN_ACTION_RESET_FACTORY_DEFAULT = "reset-factory-default"
    ADMIN_ACTION_SECURE_ERASE = "secure-erase"
    ADMIN_ACTION_UNLOCK_DIMMS = "unlock-dimms"
    ADMIN_STATE_CONFIGURE = "configure"
    ADMIN_STATE_DELETE = "delete"
    ADMIN_STATE_FORCE_CONFIGURE = "force-configure"
    ADMIN_STATE_FORCE_DELETE = "force-delete"
    ADMIN_STATE_FORCE_FLAG = "force-flag"
    ADMIN_STATE_INIT = "init"
    ADMIN_STATE_MATCHING = "matching"
    ADMIN_STATE_NOT_MATCHING = "not-matching"
    CFGD_MEMORY_PERCENTAGE_UNKNOWN = "unknown"
    NS_ADMIN_STATE_CONFIGURE = "configure"
    NS_ADMIN_STATE_DELETE = "delete"
    NS_ADMIN_STATE_FORCE_CONFIGURE = "force-configure"
    NS_ADMIN_STATE_FORCE_DELETE = "force-delete"
    NS_ADMIN_STATE_FORCE_FLAG = "force-flag"
    NS_ADMIN_STATE_INIT = "init"
    NS_ADMIN_STATE_MATCHING = "matching"
    NS_ADMIN_STATE_NOT_MATCHING = "not-matching"
    POLICY_OPERATION_DISABLE_SECURITY = "disable-security"
    POLICY_OPERATION_ENABLE_SECURITY = "enable-security"
    POLICY_OPERATION_FAILED = "failed"
    POLICY_OPERATION_HOST_MANAGED = "host-managed"
    POLICY_OPERATION_MODIFY_PASSPHRASE = "modify-passphrase"
    POLICY_OPERATION_NO_OP = "no-op"
    POLICY_OPERATION_POLICY_CHANGED = "policy-changed"


class MemoryPersistentMemoryConfiguration(ManagedObject):
    """This is MemoryPersistentMemoryConfiguration class."""

    consts = MemoryPersistentMemoryConfigurationConsts()
    naming_props = set([])

    mo_meta = MoMeta("MemoryPersistentMemoryConfiguration", "memoryPersistentMemoryConfiguration", "pmemory-config", VersionMeta.Version404a, "InputOutput", 0x7f, [], ["admin", "pn-equipment", "pn-maintenance", "pn-policy"], ['computeBoard', 'lsServer'], ['faultInst', 'memoryPersistentMemoryConfigResult', 'memoryPersistentMemoryRegion'], [None])

    prop_meta = {
        "admin_action": MoPropertyMeta("admin_action", "adminAction", "string", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["cancel-all", "disable-security", "enable-security", "modify-passphrase", "no-op", "reset-factory-default", "secure-erase", "unlock-dimms"], []),
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["configure", "delete", "force-configure", "force-delete", "force-flag", "init", "matching", "not-matching"], []),
        "cfgd_memory_percentage": MoPropertyMeta("cfgd_memory_percentage", "cfgdMemoryPercentage", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unknown"], ["1-100"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version404a, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "deployed_secure_passphrase": MoPropertyMeta("deployed_secure_passphrase", "deployedSecurePassphrase", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, 0, 32, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "inaccessible_capacity": MoPropertyMeta("inaccessible_capacity", "inaccessibleCapacity", "long", VersionMeta.Version411a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([0-9]{1,15})$""", [], []),
        "memory_capacity": MoPropertyMeta("memory_capacity", "memoryCapacity", "long", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([0-9]{1,15})$""", [], []),
        "ns_admin_state": MoPropertyMeta("ns_admin_state", "nsAdminState", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["configure", "delete", "force-configure", "force-delete", "force-flag", "init", "matching", "not-matching"], []),
        "num_of_dimms": MoPropertyMeta("num_of_dimms", "numOfDimms", "uint", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "num_of_regions": MoPropertyMeta("num_of_regions", "numOfRegions", "uint", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "persistent_memory_capacity": MoPropertyMeta("persistent_memory_capacity", "persistentMemoryCapacity", "long", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([0-9]{1,15})$""", [], []),
        "policy_operation": MoPropertyMeta("policy_operation", "policyOperation", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["disable-security", "enable-security", "failed", "host-managed", "modify-passphrase", "no-op", "policy-changed"], []),
        "reserved_capacity": MoPropertyMeta("reserved_capacity", "reservedCapacity", "long", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([0-9]{1,15})$""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "secure_passphrase": MoPropertyMeta("secure_passphrase", "securePassphrase", "string", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x20, 0, 32, None, [], []),
        "security_state": MoPropertyMeta("security_state", "securityState", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "total_capacity": MoPropertyMeta("total_capacity", "totalCapacity", "long", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([0-9]{1,15})$""", [], []),
        "unconfigured_capacity": MoPropertyMeta("unconfigured_capacity", "unconfiguredCapacity", "long", VersionMeta.Version411a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([0-9]{1,15})$""", [], []),
    }

    prop_map = {
        "adminAction": "admin_action", 
        "adminState": "admin_state", 
        "cfgdMemoryPercentage": "cfgd_memory_percentage", 
        "childAction": "child_action", 
        "deployedSecurePassphrase": "deployed_secure_passphrase", 
        "dn": "dn", 
        "inaccessibleCapacity": "inaccessible_capacity", 
        "memoryCapacity": "memory_capacity", 
        "nsAdminState": "ns_admin_state", 
        "numOfDimms": "num_of_dimms", 
        "numOfRegions": "num_of_regions", 
        "persistentMemoryCapacity": "persistent_memory_capacity", 
        "policyOperation": "policy_operation", 
        "reservedCapacity": "reserved_capacity", 
        "rn": "rn", 
        "sacl": "sacl", 
        "securePassphrase": "secure_passphrase", 
        "securityState": "security_state", 
        "status": "status", 
        "totalCapacity": "total_capacity", 
        "unconfiguredCapacity": "unconfigured_capacity", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.admin_action = None
        self.admin_state = None
        self.cfgd_memory_percentage = None
        self.child_action = None
        self.deployed_secure_passphrase = None
        self.inaccessible_capacity = None
        self.memory_capacity = None
        self.ns_admin_state = None
        self.num_of_dimms = None
        self.num_of_regions = None
        self.persistent_memory_capacity = None
        self.policy_operation = None
        self.reserved_capacity = None
        self.sacl = None
        self.secure_passphrase = None
        self.security_state = None
        self.status = None
        self.total_capacity = None
        self.unconfigured_capacity = None

        ManagedObject.__init__(self, "MemoryPersistentMemoryConfiguration", parent_mo_or_dn, **kwargs)



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import print_function

from nose.tools import assert_equal 
import ucsmsdk.ucsxmlcodec as xc
from ucsmsdk.ucscoremeta import WriteXmlOption


def test_001_knownmo_unknownprop():
    xml_str = '''
    <lsServer agentPolicyName=""
    name="ra11"
    type="instance"
    usrLbl="b"
    rn = "ls-ra11"
    unknownProps="unknown"/>'''

    obj = xc.from_xml_str(xml_str)
    obj.unknownProps = "known"
    xml_element = obj.to_xml()
    expected = b'<lsServer agentPolicyName="" dn="ls-ra11" name="ra11" type="instance" unknownProps="known" usrLbl="b" />'
    result_str = xc.to_xml_str(xml_element)
    assert_equal(result_str, expected)


def test_002_knownmo_unknownprop():
    xml_str = '''
    <lsServer agentPolicyName=""
    name="ra11"
    type="instance"
    usrLbl="b"
    rn = "ls-ra11"
    unknownProps="unknown"/>'''

    obj = xc.from_xml_str(xml_str)
    obj.unknownProps = "known"
    xml_element = obj.to_xml(option=WriteXmlOption.DIRTY)
    print(xc.to_xml_str(xml_element))



"""This module contains the general information for StorageTransportableFlashModule ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class StorageTransportableFlashModuleConsts:
    BLOCK_SIZE_512 = "512"
    BLOCK_SIZE_UNKNOWN = "unknown"
    CONNECTION_PROTOCOL_NVME = "NVME"
    CONNECTION_PROTOCOL_SAS = "SAS"
    CONNECTION_PROTOCOL_SATA = "SATA"
    CONNECTION_PROTOCOL_UNSPECIFIED = "unspecified"
    NUMBER_OF_BLOCKS_UNKNOWN = "unknown"
    OPERABILITY_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPERABILITY_AUTO_UPGRADE = "auto-upgrade"
    OPERABILITY_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPERABILITY_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPERABILITY_CHASSIS_INTRUSION = "chassis-intrusion"
    OPERABILITY_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPERABILITY_CONFIG = "config"
    OPERABILITY_DECOMISSIONING = "decomissioning"
    OPERABILITY_DEGRADED = "degraded"
    OPERABILITY_DISABLED = "disabled"
    OPERABILITY_DISCOVERY = "discovery"
    OPERABILITY_DISCOVERY_FAILED = "discovery-failed"
    OPERABILITY_EQUIPMENT_PROBLEM = "equipment-problem"
    OPERABILITY_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPERABILITY_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPERABILITY_IDENTIFY = "identify"
    OPERABILITY_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPERABILITY_INOPERABLE = "inoperable"
    OPERABILITY_LINK_ACTIVATE_BLOCKED = "link-activate-blocked"
    OPERABILITY_MALFORMED_FRU = "malformed-fru"
    OPERABILITY_NON_OPTIMAL = "non-optimal"
    OPERABILITY_NON_OPTIMAL_SEVERE = "non-optimal-severe"
    OPERABILITY_NOT_SUPPORTED = "not-supported"
    OPERABILITY_OPERABLE = "operable"
    OPERABILITY_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPERABILITY_PERFORMANCE_PROBLEM = "performance-problem"
    OPERABILITY_POST_FAILURE = "post-failure"
    OPERABILITY_POWER_PROBLEM = "power-problem"
    OPERABILITY_POWERED_OFF = "powered-off"
    OPERABILITY_REMOVED = "removed"
    OPERABILITY_THERMAL_PROBLEM = "thermal-problem"
    OPERABILITY_UNKNOWN = "unknown"
    OPERABILITY_UNSUPPORTED_CONFIG = "unsupported-config"
    OPERABILITY_UPGRADE_PROBLEM = "upgrade-problem"
    OPERABILITY_VOLTAGE_PROBLEM = "voltage-problem"
    PHYSICAL_BLOCK_SIZE_512 = "512"
    PHYSICAL_BLOCK_SIZE_UNKNOWN = "unknown"
    PRESENCE_EMPTY = "empty"
    PRESENCE_EQUIPPED = "equipped"
    PRESENCE_EQUIPPED_DEPRECATED = "equipped-deprecated"
    PRESENCE_EQUIPPED_DISC_ERROR = "equipped-disc-error"
    PRESENCE_EQUIPPED_DISC_IN_PROGRESS = "equipped-disc-in-progress"
    PRESENCE_EQUIPPED_DISC_NOT_STARTED = "equipped-disc-not-started"
    PRESENCE_EQUIPPED_DISC_UNKNOWN = "equipped-disc-unknown"
    PRESENCE_EQUIPPED_IDENTITY_UNESTABLISHABLE = "equipped-identity-unestablishable"
    PRESENCE_EQUIPPED_NOT_PRIMARY = "equipped-not-primary"
    PRESENCE_EQUIPPED_SLAVE = "equipped-slave"
    PRESENCE_EQUIPPED_UNSUPPORTED = "equipped-unsupported"
    PRESENCE_EQUIPPED_WITH_MALFORMED_FRU = "equipped-with-malformed-fru"
    PRESENCE_INACCESSIBLE = "inaccessible"
    PRESENCE_MISMATCH = "mismatch"
    PRESENCE_MISMATCH_IDENTITY_UNESTABLISHABLE = "mismatch-identity-unestablishable"
    PRESENCE_MISMATCH_SLAVE = "mismatch-slave"
    PRESENCE_MISSING = "missing"
    PRESENCE_MISSING_SLAVE = "missing-slave"
    PRESENCE_NOT_SUPPORTED = "not-supported"
    PRESENCE_UNAUTHORIZED = "unauthorized"
    PRESENCE_UNKNOWN = "unknown"
    SIZE_NOT_APPLICABLE = "not-applicable"


class StorageTransportableFlashModule(ManagedObject):
    """This is StorageTransportableFlashModule class."""

    consts = StorageTransportableFlashModuleConsts()
    naming_props = set([])

    mo_meta = MoMeta("StorageTransportableFlashModule", "storageTransportableFlashModule", "flash-module", VersionMeta.Version212a, "InputOutput", 0x3f, [], ["read-only"], ['storageRaidBattery'], [], ["Get"])

    prop_meta = {
        "block_size": MoPropertyMeta("block_size", "blockSize", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["512", "unknown"], ["0-4294967295"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version212a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "connection_protocol": MoPropertyMeta("connection_protocol", "connectionProtocol", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NVME", "SAS", "SATA", "unspecified"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], []),
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "number_of_blocks": MoPropertyMeta("number_of_blocks", "numberOfBlocks", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unknown"], ["0-18446744073709551615"]),
        "oper_qualifier_reason": MoPropertyMeta("oper_qualifier_reason", "operQualifierReason", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "operability": MoPropertyMeta("operability", "operability", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-intrusion", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "link-activate-blocked", "malformed-fru", "non-optimal", "non-optimal-severe", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "unsupported-config", "upgrade-problem", "voltage-problem"], []),
        "physical_block_size": MoPropertyMeta("physical_block_size", "physicalBlockSize", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["512", "unknown"], ["0-4294967295"]),
        "presence": MoPropertyMeta("presence", "presence", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "equipped", "equipped-deprecated", "equipped-disc-error", "equipped-disc-in-progress", "equipped-disc-not-started", "equipped-disc-unknown", "equipped-identity-unestablishable", "equipped-not-primary", "equipped-slave", "equipped-unsupported", "equipped-with-malformed-fru", "inaccessible", "mismatch", "mismatch-identity-unestablishable", "mismatch-slave", "missing", "missing-slave", "not-supported", "unauthorized", "unknown"], []),
        "revision": MoPropertyMeta("revision", "revision", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "serial": MoPropertyMeta("serial", "serial", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "size": MoPropertyMeta("size", "size", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-18446744073709551615"]),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
    }

    prop_map = {
        "blockSize": "block_size", 
        "childAction": "child_action", 
        "connectionProtocol": "connection_protocol", 
        "dn": "dn", 
        "id": "id", 
        "model": "model", 
        "numberOfBlocks": "number_of_blocks", 
        "operQualifierReason": "oper_qualifier_reason", 
        "operability": "operability", 
        "physicalBlockSize": "physical_block_size", 
        "presence": "presence", 
        "revision": "revision", 
        "rn": "rn", 
        "sacl": "sacl", 
        "serial": "serial", 
        "size": "size", 
        "status": "status", 
        "vendor": "vendor", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.block_size = None
        self.child_action = None
        self.connection_protocol = None
        self.id = None
        self.model = None
        self.number_of_blocks = None
        self.oper_qualifier_reason = None
        self.operability = None
        self.physical_block_size = None
        self.presence = None
        self.revision = None
        self.sacl = None
        self.serial = None
        self.size = None
        self.status = None
        self.vendor = None

        ManagedObject.__init__(self, "StorageTransportableFlashModule", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FabricLocale ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FabricLocaleConsts:
    C_TYPE_MUX = "mux"
    C_TYPE_MUX_ACCESS = "mux-access"
    C_TYPE_MUX_FABRIC = "mux-fabric"
    C_TYPE_MUX_FABRICPC = "mux-fabricpc"
    C_TYPE_MUX_FABRICPC_TO_CHPC = "mux-fabricpc-to-chpc"
    C_TYPE_MUX_FABRICPC_TO_HOSTPC = "mux-fabricpc-to-hostpc"
    C_TYPE_MUX_FABRICPC_TO_HOSTPORT = "mux-fabricpc-to-hostport"
    C_TYPE_MUX_FABRICPORT_TO_HOSTPC = "mux-fabricport-to-hostpc"
    C_TYPE_MUX_HOSTPC_TO_ADAPTORPC = "mux-hostpc-to-adaptorpc"
    C_TYPE_MUX_TO_APPLIANCE = "mux-to-appliance"
    C_TYPE_MUX_TO_CHASSIS = "mux-to-chassis"
    C_TYPE_MUX_TO_HOST = "mux-to-host"
    C_TYPE_SWITCH_ACCESS = "switch-access"
    C_TYPE_SWITCH_FABRIC = "switch-fabric"
    C_TYPE_SWITCH_FABRICPC = "switch-fabricpc"
    C_TYPE_SWITCH_TO_HOST = "switch-to-host"
    C_TYPE_SWITCH_TO_MUX = "switch-to-mux"
    C_TYPE_SWITCHPC_TO_HOSTPC = "switchpc-to-hostpc"
    CHASSIS_ID_N_A = "N/A"
    EVAC_STATE_DRAIN = "drain"
    EVAC_STATE_FILL = "fill"
    EVAC_STATE_UNKNOWN = "unknown"
    SIDE_LEFT = "left"
    SIDE_RIGHT = "right"
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"


class FabricLocale(ManagedObject):
    """This is FabricLocale class."""

    consts = FabricLocaleConsts()
    naming_props = set(['switchId'])

    mo_meta = MoMeta("FabricLocale", "fabricLocale", "fabric-[switch_id]", VersionMeta.Version101e, "InputOutput", 0x7f, [], ["read-only"], ['computeBlade', 'computeRackUnit', 'computeServerUnit', 'equipmentChassis', 'equipmentFex', 'mgmtController'], ['adaptorExtEthIfPc', 'dcxVc', 'fabricPath'], ["Get"])

    prop_meta = {
        "c_type": MoPropertyMeta("c_type", "cType", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["mux", "mux-access", "mux-fabric", "mux-fabricpc", "mux-fabricpc-to-chpc", "mux-fabricpc-to-hostpc", "mux-fabricpc-to-hostport", "mux-fabricport-to-hostpc", "mux-hostpc-to-adaptorpc", "mux-to-appliance", "mux-to-chassis", "mux-to-host", "switch-access", "switch-fabric", "switch-fabricpc", "switch-to-host", "switch-to-mux", "switchpc-to-hostpc"], ["0-255"]),
        "chassis_id": MoPropertyMeta("chassis_id", "chassisId", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "evac_state": MoPropertyMeta("evac_state", "evacState", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["drain", "fill", "unknown"], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "side": MoPropertyMeta("side", "side", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["left", "right"], []),
        "slot_id": MoPropertyMeta("slot_id", "slotId", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x40, None, None, None, ["A", "B", "NONE"], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
    }

    prop_map = {
        "cType": "c_type", 
        "chassisId": "chassis_id", 
        "childAction": "child_action", 
        "dn": "dn", 
        "evacState": "evac_state", 
        "locale": "locale", 
        "name": "name", 
        "rn": "rn", 
        "sacl": "sacl", 
        "side": "side", 
        "slotId": "slot_id", 
        "status": "status", 
        "switchId": "switch_id", 
        "transport": "transport", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, switch_id, **kwargs):
        self._dirty_mask = 0
        self.switch_id = switch_id
        self.c_type = None
        self.chassis_id = None
        self.child_action = None
        self.evac_state = None
        self.locale = None
        self.name = None
        self.sacl = None
        self.side = None
        self.slot_id = None
        self.status = None
        self.transport = None
        self.type = None

        ManagedObject.__init__(self, "FabricLocale", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ConfigRefreshIdentity ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigRefreshIdentity", "configRefreshIdentity", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "dn": MethodPropertyMeta("Dn", "dn", "ReferenceObject", "Version142b", "InputOutput", False),
    "in_hierarchical": MethodPropertyMeta("InHierarchical", "inHierarchical", "Xs:string", "Version142b", "Input", False),
    "in_id_type": MethodPropertyMeta("InIdType", "inIdType", "Xs:string", "Version142b", "Input", False),
    "in_is_discard_mode": MethodPropertyMeta("InIsDiscardMode", "inIsDiscardMode", "Xs:string", "Version142b", "Input", False),
    "out_ackables": MethodPropertyMeta("OutAckables", "outAckables", "ConfigMap", "Version142b", "Output", True),
    "out_affected": MethodPropertyMeta("OutAffected", "outAffected", "ConfigMap", "Version142b", "Output", True),
    "out_config": MethodPropertyMeta("OutConfig", "outConfig", "ConfigConfig", "Version142b", "Output", True),
    "out_old_ackables": MethodPropertyMeta("OutOldAckables", "outOldAckables", "ConfigMap", "Version142b", "Output", True),
    "out_old_affected": MethodPropertyMeta("OutOldAffected", "outOldAffected", "ConfigMap", "Version142b", "Output", True),
    "out_retry": MethodPropertyMeta("OutRetry", "outRetry", "Xs:unsignedShort", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "dn": "dn",
    "inHierarchical": "in_hierarchical",
    "inIdType": "in_id_type",
    "inIsDiscardMode": "in_is_discard_mode",
    "outAckables": "out_ackables",
    "outAffected": "out_affected",
    "outConfig": "out_config",
    "outOldAckables": "out_old_ackables",
    "outOldAffected": "out_old_affected",
    "outRetry": "out_retry",
}



"""This module contains the meta information of ConfigGetRemotePolicies ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigGetRemotePolicies", "configGetRemotePolicies", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_context": MethodPropertyMeta("InContext", "inContext", "ReferenceObject", "Version142b", "Input", False),
    "in_policy_digests": MethodPropertyMeta("InPolicyDigests", "inPolicyDigests", "ConfigSet", "Version142b", "Input", True),
    "in_stimulus_id": MethodPropertyMeta("InStimulusId", "inStimulusId", "Xs:unsignedLong", "Version142b", "Input", False),
    "out_policies": MethodPropertyMeta("OutPolicies", "outPolicies", "ConfigSet", "Version142b", "Output", True),
    "out_stimulus_id": MethodPropertyMeta("OutStimulusId", "outStimulusId", "Xs:unsignedLong", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inContext": "in_context",
    "inPolicyDigests": "in_policy_digests",
    "inStimulusId": "in_stimulus_id",
    "outPolicies": "out_policies",
    "outStimulusId": "out_stimulus_id",
}



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""
This module has helper methods to facilitate image download from CCO
"""

from __future__ import print_function
from __future__ import unicode_literals

import os
import logging

from .. import ucsgenutils
from ..ucsexception import UcsValidationException, UcsWarning
from ..ucsdriver import UcsDriver

from six.moves import input


log = logging.getLogger('ucs')


class _UcsCcoImageList:
    """enum for cco image attributes"""
    IDAC_TAG_VERSION = "version"
    IDAC_TAG_IMAGE_NAME = "imageName"
    IDAC_TAG_URL = "url"
    IDAC_TAG_IP_URL = "IPurl"
    IDAC_TAG_SIZE = "size"
    IDAC_TAG_CHECKSUM = "checksum"
    IDAC_TAG_FILE_DESCRIPTION = "fileDescription"


class UcsCcoImage(object):
    """
    Describes the cco image object
    """

    def __init__(self):
        self.image_name = None
        self.version = None
        self.url = None
        self.ip_url = None
        self.size = None
        self.checksum_md5 = None
        self.file_description = None
        self.network_credential = None
        self.proxy = None

    def __str__(self):
        """
        Overridden str
        """
        tab_size = 8
        out_str = "\n"
        out_str += str("image_name").ljust(tab_size * 4) + ':' + str(
            self.image_name) + "\n"
        out_str += str("version").ljust(tab_size * 4) + ':' + str(
            self.version) + "\n"
        out_str += str("url").ljust(tab_size * 4) + ':' + str(self.url) + "\n"
        out_str += str("ip_url").ljust(tab_size * 4) + ':' + str(
            self.ip_url) + "\n"
        out_str += str("size").ljust(tab_size * 4) + ':' + str(
            self.size) + "\n"
        out_str += str("checksum_md5").ljust(tab_size * 4) + ':' + str(
            self.checksum_md5) + "\n"
        out_str += str("file_description").ljust(tab_size * 4) + ':' + str(
            self.file_description) + "\n"
        out_str += str("network_credential").ljust(tab_size * 4) + ':' + str(
            self.network_credential) + "\n"
        out_str += str("proxy").ljust(tab_size * 4) + ':' + str(
            self.proxy) + "\n"
        out_str += "\n"
        return out_str


def get_ucs_cco_image_list(username=None, password=None, mdf_id_list=None,
                           proxy=None):
    """
    Gets the list of images available on CCO

    Args:
        username (str): username to connect to image server
        password (str): password to connect to image server
        mdf_id_list (list): list of mdf id
        proxy (str): proxy used for connection

    Returns:
        List of UcsCcoImage objects

    Example:
        image_list = get_ucs_cco_image_list("username", "password")
    """

    import getpass
    import xml.dom
    import xml.dom.minidom
    import base64

    if username is None:
        username = input("Username: ")
    if password is None:
        password = getpass.getpass()

    ucs_mdf_ids = (283612660, 283853163, 283862063)
    url = "https://www.cisco.com/cgi-bin/front.x/ida/locator/locator.pl"
    ida_xml_query_header = 'input_xml=<?xml version="1.0" encoding="UTF-8"?>' \
                           '<locator>' \
                           '<input>'
    ida_xml_query_mdf_id = '<mdfConcept id="%s" name=""/>'
    ida_xml_query_footer = '</input></locator>'

    # create input_xml string to post as
    # data to the respective url via post method
    input_xml = ""
    input_xml += ida_xml_query_header
    if not mdf_id_list:
        for mdf_id in ucs_mdf_ids:
            input_xml += ida_xml_query_mdf_id % mdf_id
    else:
        for mdf_id in mdf_id_list:
            input_xml += ida_xml_query_mdf_id % mdf_id

    input_xml += ida_xml_query_footer
    log.debug(input_xml)

    # base64encode for Authorization header
    credential = base64.b64encode((username + ":" + password).encode()).decode(
        'utf-8')
    log.debug(credential)

    # send request to server
    driver = UcsDriver(proxy)
    driver.add_header("Authorization", "Basic %s" % credential)
    ida_xml_response = driver.post(uri=url,
                                   data=input_xml.encode(),
                                   dump_xml=True,
                                   read=True)

    if not ida_xml_response:
        raise UcsValidationException("No Response from <%s>" % url)

    doc = xml.dom.minidom.parseString(ida_xml_response)
    image_node_list = doc.getElementsByTagName("image")

    if not image_node_list:
        raise UcsValidationException("No Images Found")

    # Serialize image nodes in objects
    cco_image_list = []
    for image_node in image_node_list:
        image = UcsCcoImage()
        image.network_credential = credential

        property_node_list = [child_node for child_node in
                              image_node.childNodes if
                              child_node.nodeType == child_node.ELEMENT_NODE
                              and child_node.localName == "property"]
        for property_node in property_node_list:
            if not property_node.hasAttribute("name"):
                continue
            if property_node.getAttribute(
                    "name") == _UcsCcoImageList.IDAC_TAG_VERSION:
                image.version = property_node.getAttribute("value")
                continue
            if property_node.getAttribute(
                    "name") == _UcsCcoImageList.IDAC_TAG_IMAGE_NAME:
                image.image_name = property_node.getAttribute("value")
                continue
            if property_node.getAttribute(
                    "name") == _UcsCcoImageList.IDAC_TAG_URL:
                image.url = property_node.getAttribute("value")
                continue
            if property_node.getAttribute(
                    "name") == _UcsCcoImageList.IDAC_TAG_IP_URL:
                image.ip_url = property_node.getAttribute("value")
                continue
            if property_node.getAttribute(
                    "name") == _UcsCcoImageList.IDAC_TAG_SIZE:
                image.size = int(property_node.getAttribute("value"))
                continue
            if property_node.getAttribute(
                    "name") == _UcsCcoImageList.IDAC_TAG_CHECKSUM:
                if property_node.getAttribute("type") == "md5":
                    image.checksum_md5 = property_node.getAttribute("value")
                    continue
            if property_node.getAttribute(
                    "name") == _UcsCcoImageList.IDAC_TAG_FILE_DESCRIPTION:
                image.file_description = property_node.getAttribute("value")
                continue

        cco_image_list.append(image)
    return cco_image_list


def get_ucs_cco_image(image, file_dir, proxy=None):
    """
    Downloads image from CCO

    Args:
        image (UcsCcoImage): object of type UcsCcoImage
        file_dir (str): directory to download image to
        proxy (str): proxy (if any)

    Returns:
        None

    Example:
        image_list = get_ucs_cco_image_list("username", "password")\n
        get_ucs_cco_image(image=image_list[0], file_dir="/home/user/images")\n
    """

    if not image:
        raise UcsValidationException("Provide an image to be downloaded.")
    if not isinstance(image, UcsCcoImage):
        raise UcsValidationException("Object is not of type UcsCcoImage")

    if not file_dir:
        raise UcsValidationException("Provide file_dir to download image to.")
    if not os.path.isdir(file_dir):
        raise UcsValidationException(
            "Not a valid directory <%s>" % file_dir)

    image_url = image.url
    print("Processing Image " + str(image.image_name))

    driver = UcsDriver(proxy)
    driver.add_header("Authorization", "Basic %s" % image.network_credential)
    ucsgenutils.download_file(driver,
                              file_url=image_url,
                              file_dir=file_dir,
                              file_name=str(image.image_name))

    local_file = os.path.join(file_dir, str(image.image_name))

    if not os.path.exists(local_file):
        raise UcsValidationException("URL parameter is not provided.")

    md5_sum = ucsgenutils.get_md5_sum(local_file)
    if not md5_sum:
        UcsWarning("Unable to generate md5sum for file <%s>" % local_file)
        UcsWarning("Deleting file <%s> ....." % local_file)
        os.remove(local_file)
        return
    log.debug(md5_sum)
    log.debug(image.checksum_md5)
    if md5_sum != image.checksum_md5:
        UcsWarning("Incorrect md5sum for file <%s>" % local_file)
        UcsWarning("Deleting file <%s> ....." % local_file)
        os.remove(local_file)
        return



"""This module contains the general information for VnicProfile ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class VnicProfileConsts:
    CDP_DISABLED = "disabled"
    CDP_ENABLED = "enabled"
    CONFIG_QUALIFIER_INVALID_NAME = "invalid-name"
    CONFIG_QUALIFIER_NORMAL = "normal"
    COS_ANY = "any"
    FORGE_MAC_ALLOW = "allow"
    FORGE_MAC_DENY = "deny"
    HOST_NW_IOPERF_HIGH_PERF_REQD = "high-perf-reqd"
    HOST_NW_IOPERF_NONE = "none"
    INT_ID_NONE = "none"
    MAC_REGISTER_MODE_ALL_HOST_VLANS = "all-host-vlans"
    MAC_REGISTER_MODE_ONLY_NATIVE_VLAN = "only-native-vlan"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    QOS_POLICY_ID_NONE = "none"
    TYPE_REGULAR = "regular"
    TYPE_SLA_ONLY = "sla-only"
    UPLINK_FAIL_ACTION_LINK_DOWN = "link-down"
    UPLINK_FAIL_ACTION_WARNING = "warning"


class VnicProfile(ManagedObject):
    """This is VnicProfile class."""

    consts = VnicProfileConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("VnicProfile", "vnicProfile", "vnic-[name]", VersionMeta.Version101e, "InputOutput", 0x7fff, [], ["admin", "ls-network", "ls-network-policy"], ['vnicProfileSet'], ['fabricNetGroupRef', 'fabricNetflowMonSrcEp', 'faultInst', 'swNetflowMonitorRef', 'vmVnicProfCl', 'vnicEtherIf', 'vnicOProfileAlias', 'vnicProfileAlias'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "cdp": MoPropertyMeta("cdp", "cdp", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["disabled", "enabled"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "config_qualifier": MoPropertyMeta("config_qualifier", "configQualifier", "string", VersionMeta.Version203a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["invalid-name", "normal"], []),
        "cos": MoPropertyMeta("cos", "cos", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["any"], ["0-6", "255-255"]),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "forge_mac": MoPropertyMeta("forge_mac", "forgeMac", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["allow", "deny"], []),
        "host_nw_io_perf": MoPropertyMeta("host_nw_io_perf", "hostNwIOPerf", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["high-perf-reqd", "none"], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "lldp": MoPropertyMeta("lldp", "lldp", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|none|transmit|receive|all),){0,4}(defaultValue|none|transmit|receive|all){0,1}""", [], []),
        "mac_register_mode": MoPropertyMeta("mac_register_mode", "macRegisterMode", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["all-host-vlans", "only-native-vlan"], []),
        "max_ports": MoPropertyMeta("max_ports", "maxPorts", "ushort", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], ["1-4096"]),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{1,31}""", [], []),
        "nw_ctrl_policy_name": MoPropertyMeta("nw_ctrl_policy_name", "nwCtrlPolicyName", "string", VersionMeta.Version102d, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "oper_nw_ctrl_policy_name": MoPropertyMeta("oper_nw_ctrl_policy_name", "operNwCtrlPolicyName", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "oper_qos_policy_name": MoPropertyMeta("oper_qos_policy_name", "operQosPolicyName", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "pin_to_group_name": MoPropertyMeta("pin_to_group_name", "pinToGroupName", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["local", "pending-policy", "policy"], []),
        "port_profile_uuid": MoPropertyMeta("port_profile_uuid", "portProfileUuid", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""(([0-9a-fA-F]){8}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){12})|0""", [], []),
        "primary_vlan_id": MoPropertyMeta("primary_vlan_id", "primaryVlanId", "uint", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["1-4093"]),
        "qos_policy_dn": MoPropertyMeta("qos_policy_dn", "qosPolicyDn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "qos_policy_id": MoPropertyMeta("qos_policy_id", "qosPolicyId", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["none"], ["0-4294967295"]),
        "qos_policy_name": MoPropertyMeta("qos_policy_name", "qosPolicyName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x800, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x1000, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x2000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "sw_a_border_aggr_port": MoPropertyMeta("sw_a_border_aggr_port", "swABorderAggrPort", "uint", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sw_a_border_port": MoPropertyMeta("sw_a_border_port", "swABorderPort", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sw_a_border_slot": MoPropertyMeta("sw_a_border_slot", "swABorderSlot", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sw_b_border_aggr_port": MoPropertyMeta("sw_b_border_aggr_port", "swBBorderAggrPort", "uint", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sw_b_border_port": MoPropertyMeta("sw_b_border_port", "swBBorderPort", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sw_b_border_slot": MoPropertyMeta("sw_b_border_slot", "swBBorderSlot", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x4000, None, None, None, ["regular", "sla-only"], []),
        "uplink_fail_action": MoPropertyMeta("uplink_fail_action", "uplinkFailAction", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["link-down", "warning"], []),
    }

    prop_map = {
        "cdp": "cdp", 
        "childAction": "child_action", 
        "configQualifier": "config_qualifier", 
        "cos": "cos", 
        "descr": "descr", 
        "dn": "dn", 
        "forgeMac": "forge_mac", 
        "hostNwIOPerf": "host_nw_io_perf", 
        "intId": "int_id", 
        "lldp": "lldp", 
        "macRegisterMode": "mac_register_mode", 
        "maxPorts": "max_ports", 
        "name": "name", 
        "nwCtrlPolicyName": "nw_ctrl_policy_name", 
        "operNwCtrlPolicyName": "oper_nw_ctrl_policy_name", 
        "operQosPolicyName": "oper_qos_policy_name", 
        "pinToGroupName": "pin_to_group_name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "portProfileUuid": "port_profile_uuid", 
        "primaryVlanId": "primary_vlan_id", 
        "qosPolicyDn": "qos_policy_dn", 
        "qosPolicyId": "qos_policy_id", 
        "qosPolicyName": "qos_policy_name", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "swABorderAggrPort": "sw_a_border_aggr_port", 
        "swABorderPort": "sw_a_border_port", 
        "swABorderSlot": "sw_a_border_slot", 
        "swBBorderAggrPort": "sw_b_border_aggr_port", 
        "swBBorderPort": "sw_b_border_port", 
        "swBBorderSlot": "sw_b_border_slot", 
        "type": "type", 
        "uplinkFailAction": "uplink_fail_action", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.cdp = None
        self.child_action = None
        self.config_qualifier = None
        self.cos = None
        self.descr = None
        self.forge_mac = None
        self.host_nw_io_perf = None
        self.int_id = None
        self.lldp = None
        self.mac_register_mode = None
        self.max_ports = None
        self.nw_ctrl_policy_name = None
        self.oper_nw_ctrl_policy_name = None
        self.oper_qos_policy_name = None
        self.pin_to_group_name = None
        self.policy_level = None
        self.policy_owner = None
        self.port_profile_uuid = None
        self.primary_vlan_id = None
        self.qos_policy_dn = None
        self.qos_policy_id = None
        self.qos_policy_name = None
        self.sacl = None
        self.status = None
        self.sw_a_border_aggr_port = None
        self.sw_a_border_port = None
        self.sw_a_border_slot = None
        self.sw_b_border_aggr_port = None
        self.sw_b_border_port = None
        self.sw_b_border_slot = None
        self.type = None
        self.uplink_fail_action = None

        ManagedObject.__init__(self, "VnicProfile", parent_mo_or_dn, **kwargs)
